# -*- coding: utf-8 -*-
"""Define the RISC utilities."""
import math
from typing import Any, Dict

from risc.__version__ import __version__ as risc_version


def get_user_agent(user_agent: str = "risc-python") -> str:
    """Get the current module version."""
    user_agent_str: str = f"{user_agent}/{risc_version}"
    return user_agent_str


def roundup(x: float) -> int:
    """Round the provided float up to the nearest tens."""
    return int(math.ceil(x / 10.0)) * 10


def determine_bytes(size: float) -> Dict[str, Any]:
    """Determine the highest denomination from bytes to KB, MB, GB, and TB.

    Args:
        size (int): The size, in bytes.

    Returns:
        dict: The dictionary mapping of highest bytes denomination and the equivalent size.

    """
    power = 2 ** 10
    n = 0
    power_labels = {0: "", 1: "K", 2: "M", 3: "G", 4: "T"}
    while size > power:
        size /= power
        n += 1
    return {"size": size, "label": f"{power_labels[n]}B"}


def format_bytes(size: float, denomination: str = "GB") -> float:
    """Convert bytes to the desired denomination.

    Args:
        size (int): The size, in bytes.
        denomination (str): The byte denomination to convert size to.
            Defaults to: GB. Options are: KB, MB, GB, and TB.

    Returns:
        float: The float formatted to the requested denomination.

    """
    bytes_map = {"KB": 2 ** 10, "MB": 1024 ** 2, "GB": 1024 ** 3, "TB": 1024 ** 4}
    if denomination not in bytes_map.keys():
        raise ValueError(
            f"Invalid option provided to format_bytes denomination argument! Options are: {bytes_map.keys()}"
        )
    converted_size: float = size / bytes_map[denomination]
    return converted_size


def handle_disk_sizing(
    total_size: str, free_size: str, fudge_factor: float = 1.5
) -> Dict[str, Any]:
    """Determine disk sizing based on the provided fudge factor and utilized space."""
    free = int(free_size)
    total = int(total_size)
    used: int = total - free
    proposed_size: float = used * fudge_factor
    recommended: float = float(
        proposed_size if proposed_size <= total and proposed_size != 0 else total
    )
    recommended_gb: float = format_bytes(recommended)
    formatted_recommendation: Dict[str, Any] = {
        "size": roundup(recommended_gb),
        "label": "GB",
    }
    return formatted_recommendation



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['risc']

package_data = \
{'': ['*'],
 'risc': ['.mypy_cache/3.8/*',
          '.mypy_cache/3.8/collections/*',
          '.mypy_cache/3.8/email/*',
          '.mypy_cache/3.8/http/*',
          '.mypy_cache/3.8/importlib/*',
          '.mypy_cache/3.8/logging/*',
          '.mypy_cache/3.8/os/*',
          '.mypy_cache/3.8/requests/*',
          '.mypy_cache/3.8/requests/packages/*',
          '.mypy_cache/3.8/requests/packages/urllib3/*',
          '.mypy_cache/3.8/requests/packages/urllib3/packages/*',
          '.mypy_cache/3.8/requests/packages/urllib3/packages/ssl_match_hostname/*',
          '.mypy_cache/3.8/requests/packages/urllib3/util/*',
          '.mypy_cache/3.8/risc/*',
          '.mypy_cache/3.8/urllib/*']}

install_requires = \
['fire>=0.3.0,<0.4.0', 'requests>=2.23.0,<3.0.0']

entry_points = \
{'console_scripts': ['risc = risc.main:main']}

setup_kwargs = {
    'name': 'risc',
    'version': '0.2.1',
    'description': 'Python client and CLI for RISC',
    'long_description': '# risc-python\n\nPython client and CLI for [RISC](https://riscnetworks.com/)\n\n[![PyPI](https://img.shields.io/pypi/v/risc) ![PyPI - Python Version](https://img.shields.io/pypi/pyversions/risc)](https://pypi.org/project/risc/) [![PyPi Publish](https://github.com/2ndWatch/risc-python/workflows/PyPi%20Publish/badge.svg)](https://2ndwatch.github.io/risc-python/) [![Documenation](https://github.com/2ndWatch/risc-python/workflows/Github%20Pages/badge.svg)](https://2ndwatch.github.io/risc-python/)\n\n## Requirements\n\n[Python 3.6+](https://www.python.org/downloads/)\n\n## Installation & Usage\n\n```sh\npyenv install 3.7\npip(env) install risc\n```\n',
    'author': 'Mark Beacom',
    'author_email': 'mbeacom@2ndwatch.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/2ndWatch/risc-python',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
